"""Version information for Cursus."""

__version__ = "1.1.1"
__title__ = "cursus"
__description__ = "Automatic SageMaker Pipeline Generation from DAG Specifications"
__author__ = "Tianpei Xie"
__author_email__ = "unidoctor@gmail.com"
__license__ = "MIT"
__url__ = "https://github.com/TianpeiLuke/cursus"
