"""
Discovery package for alignment validation.

Provides engines for discovering and mapping various component files.
"""

from .contract_discovery import ContractDiscoveryEngine

__all__ = ['ContractDiscoveryEngine']
